import { Document, Page, Text, View, Image } from "@react-pdf/renderer";
import { TransactionListType } from "../Types/Types";
import { colors } from "../../styles";
import count_transaction_equipments from "../../CountTransactionEquipments/CountTransactionEquipments";
import {
  filter_today,
  filter_thismonth,
} from "../FilterTransaction/FilterTransaction";
import ustplogo from "../../assets/ustp-logo.png";

type props = {
  transactions: TransactionListType | [];
  filter: "Day" | "Month";
};

export default function TransactionReportPDF(props: props) {
  const transactions_today = filter_today(props.transactions);
  const transactions_thismonth = filter_thismonth(props.transactions);
  return (
    <Document>
      <Page size={"A4"}>
        {/* Header */}
        <View
          style={{
            display: "flex",
            flexDirection: "row",
            alignItems: "center",
            justifyContent: "center",
            alignSelf: "stretch",
            padding: 60,
          }}
        >
          <Image
            src={ustplogo}
            style={{
              width: 70,
              height: 70,
              position: "absolute",
              left: "45",
              top: "",
            }}
          />

          <View
            style={{
              width: "100%",
              height: "auto",
              position: "absolute",
              right: "30",
              top: "35",
            }}
          >
            <View style={{ alignItems: "center" }}>
              <Text
                style={{
                  color: colors.form_dark,
                  fontSize: 11,
                  textAlign: "center",
                }}
              >
                Republic of the Philippines{"\n"}
                <Text style={{ fontFamily: "Helvetica-Bold" }}>
                  {" "}
                  UNIVERSITY OF SCIENCE and TECHNOLOGY OF SCIENCE AND TECHNOLOGY{" "}
                </Text>
                {"\n"}
                College of Science and Mathematics
              </Text>
              <Text
                style={{
                  color: colors.form_dark,
                  fontSize: 11,
                  textAlign: "center",
                  margin: "2 5 2 5",
                }}
              >
                <Text style={{ fontFamily: "Helvetica-Bold" }}>
                  {" "}
                  Department of Chemistry (Laboratory)
                </Text>
              </Text>
            </View>
          </View>
        </View>
        <Text
          style={{
            color: colors.form_dark,
            fontSize: 13,
            padding: "5 0 5 0",
            textAlign: "center",
          }}
        >
          <Text style={{ fontFamily: "Helvetica-Bold" }}>
            LABORATORY REPORTS
          </Text>
        </Text>

        <View
          style={{
            display: "flex",
            flexDirection: "column",
            alignItems: "center",
            alignSelf: "center",
            width: "85%",
          }}
        >
          <View
            style={{
              display: "flex",
              padding: "0px 12px",
              justifyContent: "center",
              alignItems: "center",
              gap: "10px",
              alignSelf: "stretch",
              border: "1px solid #000",
            }}
          >
            <Text
              style={{
                fontFamily: "Helvetica-Bold",
                color: colors.form_dark,
                fontSize: 13,
                padding: "5 0 5 0",
              }}
            >
              Transaction
            </Text>
          </View>
          <View
            style={{
              display: "flex",
              padding: "5px 12px",
              flexDirection: "column",
              justifyContent: "center",
              alignItems: "flex-start",
              gap: "10px",
              alignSelf: "stretch",
              borderRight: "1px solid #000",
              borderBottom: "1px solid #000",
              borderLeft: "1px solid #000",
            }}
          >
            <Text style={{ fontSize: 13 }}>Daily Transaction Report</Text>
            <Text
              style={{
                fontSize: 13,
                textAlign: "center",
              }}
            >
              {" "}
              • Total Equipments Processed:{" "}
              {count_transaction_equipments(transactions_today)}
            </Text>

            <Text
              style={{
                fontSize: 13,
                textAlign: "center",
              }}
            >
              {" "}
              • Total Transactions: {transactions_today.length}
            </Text>

            <Text
              style={{
                fontSize: 13,
                textAlign: "center",
              }}
            >
              {" "}
              • Rejected Transactions:{" "}
              {
                transactions_today.filter(
                  (transaction) => transaction.transaction_status == "Rejected"
                ).length
              }
            </Text>

            <Text
              style={{
                fontSize: 13,
                textAlign: "center",
              }}
            >
              {" "}
              • Finalized Transactions:{" "}
              {
                transactions_today.filter(
                  (transaction) => transaction.transaction_status == "Finalized"
                ).length
              }
            </Text>
          </View>
          <View
            style={{
              display: "flex",
              padding: "5px 12px",
              flexDirection: "column",
              justifyContent: "center",
              alignItems: "flex-start",
              gap: "10px",
              alignSelf: "stretch",
              borderRight: "1px solid #000",
              borderBottom: "1px solid #000",
              borderLeft: "1px solid #000",
            }}
          >
            <Text style={{ fontSize: 13 }}>Monthly Transaction Report</Text>
            <Text
              style={{
                fontSize: 13,
                textAlign: "center",
              }}
            >
              {" "}
              • Total Equipments Processed:{" "}
              {count_transaction_equipments(transactions_thismonth)}
            </Text>

            <Text
              style={{
                fontSize: 13,
                textAlign: "center",
              }}
            >
              {" "}
              • Total Transactions: {transactions_thismonth.length}
            </Text>

            <Text
              style={{
                fontSize: 13,
                textAlign: "center",
              }}
            >
              {" "}
              • Rejected Transactions:{" "}
              {
                transactions_thismonth.filter(
                  (transaction) => transaction.transaction_status == "Rejected"
                ).length
              }
            </Text>

            <Text
              style={{
                fontSize: 13,
                textAlign: "center",
              }}
            >
              {" "}
              • Finalized Transactions:{" "}
              {
                transactions_thismonth.filter(
                  (transaction) => transaction.transaction_status == "Finalized"
                ).length
              }
            </Text>
          </View>
        </View>
      </Page>
    </Document>
  );
}
